#[non_exhaustive]pub enum CodecNameReason {
Unsupported,
}Expand description
Reason a codec name could not be resolved, used in error messages.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Unsupported
The codec name is not one of the supported multicodec names.